Index: /trunk/src/VBox/Runtime/r3/posix/localipc-posix.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/posix/localipc-posix.cpp	(revision 58292)
+++ /trunk/src/VBox/Runtime/r3/posix/localipc-posix.cpp	(revision 58293)
@@ -662,5 +662,5 @@
 
 
-RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
+RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuf, size_t cbToRead, size_t *pcbRead)
 {
     /*
@@ -690,5 +690,5 @@
                     AssertRCBreak(rc);
 
-                    rc = RTSocketRead(pThis->hSocket, pvBuffer, cbBuffer, pcbRead);
+                    rc = RTSocketRead(pThis->hSocket, pvBuf, cbToRead, pcbRead);
 
                     /* Detect broken pipe. */
@@ -726,5 +726,5 @@
 
 
-RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuffer, size_t cbBuffer)
+RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuf, size_t cbToWrite)
 {
     /*
@@ -754,5 +754,5 @@
                     AssertRCBreak(rc);
 
-                    rc = RTSocketWrite(pThis->hSocket, pvBuffer, cbBuffer);
+                    rc = RTSocketWrite(pThis->hSocket, pvBuf, cbToWrite);
 
                     int rc2 = RTCritSectEnter(&pThis->CritSect);
Index: /trunk/src/VBox/Runtime/r3/win/localipc-win.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/win/localipc-win.cpp	(revision 58292)
+++ /trunk/src/VBox/Runtime/r3/win/localipc-win.cpp	(revision 58293)
@@ -795,10 +795,10 @@
 
 
-RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
+RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuf, size_t cbToRead, size_t *pcbRead)
 {
     PRTLOCALIPCSESSIONINT pThis = (PRTLOCALIPCSESSIONINT)hSession;
     AssertPtrReturn(pThis, VERR_INVALID_HANDLE);
     AssertReturn(pThis->u32Magic == RTLOCALIPCSESSION_MAGIC, VERR_INVALID_HANDLE);
-    AssertPtrReturn(pvBuffer, VERR_INVALID_POINTER);
+    AssertPtrReturn(pvBuf, VERR_INVALID_POINTER);
     /* pcbRead is optional. */
 
@@ -811,5 +811,4 @@
             pThis->cRefs++;
 
-            size_t cbToRead = cbBuffer;
             size_t cbTotalRead = 0;
             while (cbToRead > 0)
@@ -825,5 +824,5 @@
                 RTCritSectLeave(&pThis->CritSect);
 
-                if (ReadFile(pThis->hNmPipe, pvBuffer,
+                if (ReadFile(pThis->hNmPipe, pvBuf,
                              cbToRead <= ~(DWORD)0 ? (DWORD)cbToRead : ~(DWORD)0,
                              &cbRead, &pThis->OverlappedIO))
@@ -857,5 +856,5 @@
                 cbToRead    -= cbRead;
                 cbTotalRead += cbRead;
-                pvBuffer     = (uint8_t *)pvBuffer + cbRead;
+                pvBuf     = (uint8_t *)pvBuf + cbRead;
             }
 
@@ -948,11 +947,11 @@
 
 
-RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuffer, size_t cbBuffer)
+RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuf, size_t cbToWrite)
 {
     PRTLOCALIPCSESSIONINT pThis = (PRTLOCALIPCSESSIONINT)hSession;
     AssertPtrReturn(pThis, VERR_INVALID_HANDLE);
     AssertReturn(pThis->u32Magic == RTLOCALIPCSESSION_MAGIC, VERR_INVALID_HANDLE);
-    AssertPtrReturn(pvBuffer, VERR_INVALID_POINTER);
-    AssertReturn(cbBuffer, VERR_INVALID_PARAMETER);
+    AssertPtrReturn(pvBuf, VERR_INVALID_POINTER);
+    AssertReturn(cbToWrite, VERR_INVALID_PARAMETER);
 
     int rc = RTCritSectEnter(&pThis->CritSect);
@@ -988,5 +987,5 @@
                  */
                 size_t cbTotalWritten = 0;
-                while (cbBuffer > 0)
+                while (cbToWrite > 0)
                 {
                     BOOL fRc = ResetEvent(pThis->OverlappedIO.hEvent); Assert(fRc == TRUE);
@@ -995,6 +994,6 @@
 
                     DWORD cbWritten = 0;
-                    fRc = WriteFile(pThis->hNmPipe, pvBuffer,
-                                    cbBuffer <= ~(DWORD)0 ? (DWORD)cbBuffer : ~(DWORD)0,
+                    fRc = WriteFile(pThis->hNmPipe, pvBuf,
+                                    cbToWrite <= ~(DWORD)0 ? (DWORD)cbToWrite : ~(DWORD)0,
                                     &cbWritten, &pThis->OverlappedIO);
                     if (fRc)
@@ -1034,7 +1033,7 @@
 
                     /* Advance. */
-                    pvBuffer        = (char const *)pvBuffer + cbWritten;
+                    pvBuf           = (char const *)pvBuf + cbWritten;
                     cbTotalWritten += cbWritten;
-                    cbBuffer       -= cbWritten;
+                    cbToWrite      -= cbWritten;
                 }
             }

Index: /trunk/include/iprt/localipc.h
===================================================================
--- /trunk/include/iprt/localipc.h	(revision 58292)
+++ /trunk/include/iprt/localipc.h	(revision 58293)
@@ -152,13 +152,11 @@
  *
  * @param   hSession            The session handle.
- * @param   pvBuffer            Where to store the data.
- * @param   cbBuffer            If pcbRead is non-NULL this indicates the maximum number of
- *                              bytes to read. If pcbRead is NULL then this is the exact number
- *                              of bytes to read.
- * @param   pcbRead             Optional argument for indicating a partial read and returning
- *                              the number of bytes actually read.
- *                              This may return 0 on some implementations?
- */
-RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuffer, size_t cbBuffer, size_t *pcbRead);
+ * @param   pvBuf               Where to store the data.
+ * @param   cbToRead            How much to read.  This is exact request if
+ *                              pcbRead is NULL, otherwise it's an upper limit.
+ * @param   pcbRead             Optional argument for indicating a partial read
+ *                              and returning the number of bytes actually read.
+ */
+RTDECL(int) RTLocalIpcSessionRead(RTLOCALIPCSESSION hSession, void *pvBuf, size_t cbToRead, size_t *pcbRead);
 
 /**
@@ -166,5 +164,5 @@
  *
  * This may or may not block until the data is received by the other party,
- * this is an implementation detail. If you want to make sure that the data
+ * this is an implementation detail.  If you want to make sure that the data
  * has been received you should always call RTLocalIpcSessionFlush().
  *
@@ -173,8 +171,8 @@
  *
  * @param   hSession            The session handle.
- * @param   pvBuffer            The data to write.
- * @param   cbBuffer            The number of bytes to write.
- */
-RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuffer, size_t cbBuffer);
+ * @param   pvBuf               The data to write.
+ * @param   cbToWrite           How much to write.
+ */
+RTDECL(int) RTLocalIpcSessionWrite(RTLOCALIPCSESSION hSession, const void *pvBuf, size_t cbToWrite);
 
 /**